@@ -32,6 +32,11 @@
 typedef uint32_t u_int32_t;
 #endif
 
+#ifdef __APPLE__
+/* fopen is 64-bit aware on Mac OS X */
+#define fopen64(A,B) fopen(A,B)
+#endif
+
 #include "dvdauthor.h"
 #include "da-internal.h"
 #include "libauthor.h"
