@@ -15,17 +15,20 @@ COMMENTAIRE :
 #ifndef __AVANCEMENT_H__
 #define __AVANCEMENT_H__
 
+#include <gnome.h>
 #include "tampon.h"
 
-/*@$#[avancement.c] global proto. AutoProtoSigV1.1. date: 106/01/31 22:33:24 */
+/*@$#[avancement.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:15:03 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
+/* avancement.c */
 void PushAvancement PROTO((void));
 void PopAvancement PROTO((void));
 void InitAvancement PROTO((int sectors));
-void CreateAvancement PROTO((GtkWidget * forme));
+void CreateAvancement PROTO((GtkWidget *forme));
+void HideMpegVisu PROTO((void));
 void DestroyAvancement PROTO((void));
 int Avancement PROTO((int lenReaded));
 int AvancementAbs PROTO((long pos));
@@ -33,9 +36,11 @@ void SetTotalSize PROTO((long long tSize));
 void SetTotalSteps PROTO((int steps));
 void NewStep PROTO((void));
 int AvancementUi PROTO((Tampon *tampon));
-int AvancementUi2 PROTO((double pct));
+int AvancementUi2 PROTO((double pcts));
 void DisplayAvancement PROTO((char *format, ...));
-void TotalTime( char * string );
+void TotalTime PROTO((char *string));
+void ResetUserStop PROTO((void));
+int IsUserStop PROTO((void));
 #ifdef __cplusplus
 }
 #endif
