@@ -7,6 +7,7 @@
 
 
 #define CTEST( x )		/****/
+#define CTEST99( x )		x/****/
 
 #include "callbacks.h"
 #include "interface.h"
@@ -20,12 +21,14 @@
 #include "dvdcopy.h"
 #include "dvdbackup.h"
 #include "dvd2vob.h"
+#include "dvd2avi.h"
 #include "uitools.h"
 #include "message.h"
 #include "avancement.h"
 #include "globals.h"
 #include "main.h"
 #include "mpeg2dec.h"
+#include "profile.h"
 
 typedef struct
 {
@@ -54,7 +57,7 @@ static gboolean RecordAudioSelected(	GtkTreeModel  *model,
 	if( bool ) {
 		int noPiste;
 
-		gtk_tree_model_get( model, iter, AUDIO_COL7_NO, &noPiste, -1);
+		gtk_tree_model_get( model, iter, AUDIO_COL8_NO, &noPiste, -1);
 		CTEST(fprintf(stderr,"PisteAudio %d selected\n", noPiste ););
 		SelInfo.audioMap.audioTracks[noPiste] = 1;
 		SelInfo.nbAudio++;
@@ -151,7 +154,30 @@ on_proprietes_clicked                  (GtkToolButton   *toolbutton,
 {
 	GtkWidget * parent = lookup_widget(GTK_WIDGET(toolbutton), "main" );
 
+	g_assert( parent );
 	DialogPropriete( parent );
+	{/* Update media */
+		char title[512];
+		int dvdFormat = ConfigGetInt( KEY_MEDIA, DVD5 );
+		Profile_t * p = GetProfile( dvdFormat );
+		CTEST(fprintf(stderr,"%s: dvdFormat=%d p=%p\n", __FUNCTION__, dvdFormat, p ););
+		if( !p ) {
+			dvdFormat = DVD5;
+			p = GetProfile( dvdFormat );
+			g_assert( p );
+		}
+		if( p->profileFlags & PROFILE_AVAIL_F ) {
+			SetFormat( dvdFormat );
+		}
+		else {
+			dvdFormat = DVD5;
+			SetFormat( dvdFormat );
+			p = GetProfile( dvdFormat );
+			g_assert( p );
+		}
+		sprintf( title, "%s : %s",  _("DVD 9 to 5"), p->libel );
+		gtk_window_set_title( GTK_WINDOW(parent), title );
+	}
 	DeviceChecking( parent );
 	GetSelected( parent );
 	if( SelInfo.noPisteVideo != -1 ) {
@@ -243,7 +269,6 @@ on_choixiso_clicked                    (GtkButton       *button,
 	fc = create_ChoixFichier();
 	if( fc ) {
 		GtkFileFilter * fi =  gtk_file_filter_new();
-		GtkWidget * item;
 
 		gtk_file_filter_set_name( fi, _("Fichiers ISO") );
 		gtk_file_filter_add_pattern( fi, "*.iso" );
@@ -254,6 +279,7 @@ on_choixiso_clicked                    (GtkButton       *button,
 
 			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(fc));
 			strcpy( Device, filename );
+			DeviceSpecifiedF = 1;
 			g_free (filename);
 		}
 		gtk_widget_destroy( fc );
@@ -331,6 +357,7 @@ on_Encoder_clicked                     (GtkToolButton   *toolbutton,
 	double facteur;
 	double pct;
 	int res;
+	Profile_t * p;
 
 	g_assert( forme );
 	GetSelected( forme );
@@ -350,25 +377,36 @@ on_Encoder_clicked                     (GtkToolButton   *toolbutton,
 		MessageBoxError( _("Veuillez selectionner une piste audio") );
 		return;
 	}
+	p = GetProfile( GetFormat() );
+	g_assert( p );
 
-	if( facteur < 0 ) {
-		MessageBoxError( _("Veuillez lancer un calcul de qualit") );
-		return;
-	}
 	CreateDirectorys();
-	if( ConfigGetInt( KEY_USEMENU, 0 ) ) {
-		res = BackupDvd(	forme,
+	if( p->profileFlags & PROFILE_AVI_F ) {
+		res = DvdToAvi(		forme,
 					SelInfo.noPisteVideo,
 					&SelInfo.audioMap,
 					&SelInfo.subMap,
-					facteur );
+					GetFormat() );
 	}
 	else {
-		res = CopyDvd(		forme,
-					SelInfo.noPisteVideo,
-					&SelInfo.audioMap,
-					&SelInfo.subMap,
-					facteur );
+		if( facteur < 0 ) {
+			MessageBoxError( _("Veuillez lancer un calcul de qualit") );
+			return;
+		}
+		if( ConfigGetInt( KEY_USEMENU, 0 ) ) {
+			res = BackupDvd(	forme,
+						SelInfo.noPisteVideo,
+						&SelInfo.audioMap,
+						&SelInfo.subMap,
+						facteur );
+		}
+		else {
+			res = CopyDvd(		forme,
+						SelInfo.noPisteVideo,
+						&SelInfo.audioMap,
+						&SelInfo.subMap,
+						facteur );
+		}
 	}
 	DBG('c',{char timeStr[100]; TotalTime( timeStr ); fprintf(stderr,"Temps de traitement: %s\n", timeStr );});
 	if( res != -1 ) {
