@@ -86,19 +86,27 @@ static double AuthorlPct = -1;
 static int AuthorFixStage = 0;
 static long long AuthorSize;
 
-/*@$#[dvd2vob.c] static proto. AutoProtoSigV1.1. date: 106/02/16 21:33:23 */
+/*@$#[dvd2vob.c] static proto. AutoProtoSigV1.1. date: 2009/02/04 23:14:33 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
+/* dvd2vob.c */
 static void AddVobus PROTO((Cell_t *c, char *buffer, int len, uint32_t position, int curVob));
 static int Output PROTO((unsigned char *buffer, int len, char *targetDir));
 static void FindCellStart PROTO((Cell_t *c));
 static void MakeRoom PROTO((VapContext_t *c, int size));
+static uint32_t _FindNextVobu PROTO((VapContext_t *c));
 static int Readin PROTO((void *parm, unsigned char *buffer, int size));
 static int OutputFlux PROTO((void *parm, unsigned char *buffer, int size));
 static int CopyCell PROTO((Cell_t *c, char *targetDir));
 static void FreeAll PROTO((void));
+static char *BuildAudioString PROTO((int noPisteVideo, AudioMap_t *audioMap));
+static char *BuildFormatString PROTO((int noPisteVideo));
+static char *BuildSubString PROTO((int noPisteVideo, SubMap_t *subMap));
+static void AuthorProgress PROTO((char *string));
+static int ExecuteDvdAuthor PROTO((int argc, char **argv, long long size));
+static double ReCpuFactor PROTO((void));
 #ifdef __cplusplus
 }
 #endif
@@ -610,7 +618,7 @@ static int _readline( FILE * fp, char * line, int size )
 Linux!jef 2005/12/20 22:17:17
 ------------------------------------------------------------------------------*/
 
-int ExecuteDvdAuthor( char * sysCmd, long long size )
+static int ExecuteDvdAuthor( char * sysCmd, long long size )
 {
 	FILE * fp;
 	char line[1024];
@@ -719,7 +727,7 @@ static void AuthorProgress( char * string )
 Linux!jef 2005/12/20 22:17:17
 ------------------------------------------------------------------------------*/
 
-int ExecuteDvdAuthor( int argc, char ** argv, long long size )
+static int ExecuteDvdAuthor( int argc, char ** argv, long long size )
 {
 	int res;
 
@@ -738,7 +746,7 @@ int ExecuteDvdAuthor( int argc, char ** argv, long long size )
 Linux!jef 2006/02/20 22:30:41
 ------------------------------------------------------------------------------*/
 
-static double ReCpuFactor( )
+static double ReCpuFactor(void)
 {
 	double dFactor;
 	long long videoSize;
@@ -840,7 +848,7 @@ int CopyDvd( GtkWidget * forme, int noPisteVideo, AudioMap_t * audioMap, SubMap_
 {
 	GtkWidget * item;
 	char * tmpDir = ConfigGetString( KEY_TEMP, "/tmp" );
-	char * isoDir = ConfigGetString( KEY_ISODIR, "/tmp" );
+	char * isoDir = ConfigGetString( KEY_ISODIR, GetEnv( "HOME", "/tmp" ) );
 	int lastCellF = ConfigGetInt( KEY_GENERIQUE, 0 );
 	char targetDir[512];
 	char sysCmd[10240]; /*KK:*/
@@ -908,9 +916,9 @@ fprintf(stderr,"FsFree(%lld) GetWantedBytes(%lld)\n", FsFree( isoDir ), GetWante
 				ret = -1; goto out;
 			}
 			sprintf( sysCmd,"rm -rf \"%s/VIDEO_TS\"", targetDir );
-			system( sysCmd );
+			res = system( sysCmd );
 			sprintf( sysCmd,"rm -rf \"%s/AUDIO_TS\"", targetDir );
-			system( sysCmd );
+			res = system( sysCmd );
 			break;
 		case -1 :
 			MessageBoxError( _("%s n'est pas un repertoire ! Veuillez l'effacer."), targetDir );
@@ -918,9 +926,9 @@ fprintf(stderr,"FsFree(%lld) GetWantedBytes(%lld)\n", FsFree( isoDir ), GetWante
 			break;
 	}
 	sprintf( sysCmd,"mkdir -p \"%s/VIDEO_TS\"", targetDir );
-	system( sysCmd );
+	res = system( sysCmd );
 	sprintf( sysCmd,"mkdir -p \"%s/AUDIO_TS\"", targetDir );
-	system( sysCmd );
+	res = system( sysCmd );
 
 	sprintf( injectionFile, "%s/vapinj.%d", tmpDir, getpid());
 	sprintf( vobFile, "%s/%s.vob", tmpDir, TitreDvd );
@@ -974,7 +982,7 @@ fprintf(stderr,"FsFree(%lld) GetWantedBytes(%lld)\n", FsFree( isoDir ), GetWante
 		if( c->selected ) {
 			NewStep();
 			if( dynQual ) {
-				double nFactor = ReCpuFactor( factor );
+				double nFactor = ReCpuFactor();
 				if( nFactor ) {
 					double pct;
 
@@ -1118,7 +1126,8 @@ author:;
 					if( res != 1 )	break;
 				case 0 :
 					DisplayAvancement( _("Construction de l'image ISO.\n") );
-					sprintf( sysCmd, "mkisofs -dvd-video -V \"%s\"  -o \"%s\" \"%s\"",
+					sprintf( sysCmd, "%s -dvd-video -V \"%s\"  -o \"%s\" \"%s\"",
+						GetMkIsoTool(),
 						TitreDvd,
 						isoName,
 						targetDir );
@@ -1136,9 +1145,9 @@ author:;
 			DisplayAvancement( _("Gravage sur DVD.\n") );
 			DvdClose();
 			sprintf( sysCmd, "eject %s", Device );
-			system( sysCmd );
+			res = system( sysCmd );
 			sprintf( sysCmd,"k3b \"%s/VIDEO_TS\" -videodvd", targetDir );
-			system( sysCmd );
+			res = system( sysCmd );
 			DvdOpen( Device );
 		}
 	}
@@ -1149,11 +1158,13 @@ author:;
 	if( remove ) {
 		DisplayAvancement( _("Effacement des fichiers.\n"));
 		sprintf( sysCmd, "rm -rf \"%s\"", targetDir );
-		system( sysCmd );
+		res = system( sysCmd );
 	}
 #endif
 
+#if TEST_AUTHOR == 2
 out2:;
+#endif
 	DestroyAvancement();
 	FreeAll();
 	if( !ret )
