@@ -25,11 +25,12 @@ COMMENTAIRE :
 #include "systools.h"
 #include "dvdtools.h"
 
-/*@$#[dvdcell.c] static proto. AutoProtoSigV1.1. date: 107/12/17 23:14:24 */
+/*@$#[dvdcell.c] static proto. AutoProtoSigV1.1. date: 2009/02/04 23:16:18 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
+/* dvdcell.c */
 static int IsSelected PROTO((Cell_t *c, int noPisteVideo));
 static int CellExist PROTO((CellArray_t *ca, int vts, uint32_t *start, uint32_t *end));
 static void UnSelectLastCell PROTO((CellArray_t *ca));
@@ -95,6 +96,7 @@ Vobu_t * NewVobu( VobuArray_t * va, uint32_t oldSector )
 	v->idx = idx;
 	v->oldSector = oldSector;
 //!!	DBG('b',fprintf(stderr,"%s: idx: %d\n", __FUNCTION__, idx ););
+///	DBG('v',fprintf(stderr,"%s: oldSector %u\n", __FUNCTION__, oldSector ););
 
 	va->nbVobu++;
 	return( v );
@@ -201,31 +203,51 @@ Linux!jef 2005/12/28 21:18:16
 
 int BuildCells( int noPisteVideo, CellArray_t * ca, int lastF )
 {
-	int nrTS = Ifo_zero->vmgi_mat->vmg_nr_of_title_sets;
+	int nrTS = Ifo_zero->vmgi_mat->vmg_nr_of_title_sets; /* Number of title sets */
 	int i,j,k;
 
 	DBG('b',fprintf(stderr,"%s: nrTS=%d noPisteVideo=%d\n", __FUNCTION__, nrTS, noPisteVideo ););
 	for( k = 1; k <= nrTS; k++ ) {
 		ifo_handle_t * ifo = Ifo[k];
 		int vts_ttn, title_set_nr;
+		int nbChapter;
 
 		if( !ifo->vtsi_mat )	continue;
 		DBG('b',fprintf(stderr,"VTS: %d PGCS: %d ifo: %p\n", k, ifo->vts_pgcit->nr_of_pgci_srp, ifo ););
 
-		vts_ttn = Ifo_zero->tt_srpt->title[noPisteVideo].vts_ttn;
-		title_set_nr = Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr;
+		vts_ttn = Ifo_zero->tt_srpt->title[noPisteVideo].vts_ttn; /* Title number within VTS */
+DBG('b',fprintf(stderr,"NumberOfAngles: %d\n", Ifo_zero->tt_srpt->title[noPisteVideo].nr_of_angles ););
+		title_set_nr = Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr; /* Video Title Set number, VTSN */
+DBG('b', fprintf(stderr,"nr_of_srpts=%d\n", Ifo[title_set_nr]->vts_ptt_srpt->nr_of_srpts ););
 
+		g_assert( vts_ttn <= Ifo[title_set_nr]->vts_ptt_srpt->nr_of_srpts );
+		nbChapter = Ifo[title_set_nr]->vts_ptt_srpt->title[vts_ttn - 1].nr_of_ptts;
+DBG('b', fprintf(stderr,"(nbChapter) nr_of_ptts=%d\n", nbChapter ););
+/* vts_ttn -1 because array is 0 based and number is 1 based */
 		i = Ifo[title_set_nr]->vts_ptt_srpt->title[vts_ttn - 1].ptt[0].pgcn - 1;
-//		for( i = 0; i < ifo->vts_pgcit->nr_of_pgci_srp; i++ )
-		{
+DBG('b', fprintf(stderr,"title_set_nr=%d vts_ttn=%d pgcIndex=%d nbPgc=%d\n", title_set_nr, vts_ttn, i, ifo->vts_pgcit->nr_of_pgci_srp ););
+//		for( i = 0; i < nbChapter; i++ ) {
+		if( i < ifo->vts_pgcit->nr_of_pgci_srp ) {
 			pgc_t * pgc = ifo->vts_pgcit->pgci_srp[i].pgc;
-			cell_playback_t * cell_playback = pgc->cell_playback;
-			int nr = pgc->nr_of_cells;
+			cell_playback_t * cell_playback;
+			cell_position_t * cell_position;
+			int nr;
+
+			g_assert( i < ifo->vts_pgcit->nr_of_pgci_srp );
+
+			cell_playback = pgc->cell_playback;
+			cell_position = pgc->cell_position;
+			nr = pgc->nr_of_cells;
 			DBG('b',fprintf(stderr,"NrOfCells: %d\n", nr ););
 			for( j = 0; j < nr; j++ ) {
 				uint32_t start = cell_playback[j].first_sector;
 				uint32_t end = cell_playback[j].last_sector;
 
+DBG('b',fprintf(stderr,"%s: cell(%d) b_type=0x%x b_mode=0x%x at %u=>%u ", __FUNCTION__, j, cell_playback[j].block_type, cell_playback[j].block_mode, start, end ););
+DBG('b',fprintf(stderr,"vobid: %d zero_1: %d cell_id: %d\n",cell_position[j].vob_id_nr, cell_position[j].zero_1, cell_position[j].cell_nr ););
+				if( cell_position[j].zero_1 )	continue;
+
+
 				if( !CellExist( ca, k, &start, &end ) ) {
 					Cell_t * c = NewCell( ca );
 
