@@ -8,6 +8,7 @@ CREATEUR    : [Linux!jef]
 
 COMMENTAIRE :
 		Released under GPL license, see gnu.org
+ * encoding     UTF8 !-UTF8-!
 ================================================================================
 	COPY sans garder les menus
 ==============================================================================*/
@@ -40,40 +41,136 @@ COMMENTAIRE :
 #include "avancement.h"
 #include "dvdcopy.h"
 #include "const.h"
+#include "profile.h"
 
 #define IsValidAudioTrack( pgc, t )		(( pgc->audio_control[t] >> 8) != 0 )
 #define IsValidSubpTrack( pgc, t )		(( pgc->subp_control[t] >> 24) != 0 )
 
 #define BCD2INT( v )		(((v & 0xf0) >> 3) * 5 + (v & 0x0f))
 
-static char *_AudioFormat[7] = { "AC-3", "?", "MPEG1", "MPEG2", "LPCM ", "SDDS ", "DTS" };
-// static char *AudioType[5] = { "Undefined", "Normal", "Impaired", "Comments1", "Comments2" };
+// static char *_AudioFormat[7] = { "AC3", "?", "MPEG1", "MPEG2", "LPCM ", "SDDS ", "DTS" };
+// static char *_AudioType[5] = { "", "Normal", "Impaired", "Director's comments", "Alternate director's comments" };
+/*
 static char *SubpType[16] = {
 	"", "Normal", "Large", "Children", "reserved", "Normal_CC",
 	"Large_CC", "Children_CC",
 	"reserved", "Forced", "reserved", "reserved", "reserved", "Director",
 	"Large_Director", "Children_Director"
 };
+*/
 
 static char * AspectRatio[4] = {"4:3", "16:9", "\"?:?\"", "16:9"};
 
 static char TitreDvd[128];
 
-/*@$#[dvdcopy.c] static proto. AutoProtoSigV1.1. date: 106/02/22 22:09:18 */
+/*@$#[dvdcopy.c] static proto. AutoProtoSigV1.1. date: 2009/06/04 21:09:17 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
-static int NrOfSubp PROTO((vtsi_mat_t *vtsi_mat, pgc_t *pgc));
-static int SubpId PROTO((unsigned int control));
-static unsigned long GetSector PROTO((int chapitre, pgc_t *pgc));
-static unsigned short SubCode PROTO((int noPisteVideo, int noSubtitle));
-static double DefaultRequantFactor PROTO((int noPisteVideo, AudioMap_t *audioMap, SubMap_t *subMap, int useMenuF));
+static char *_AudioFormat(int format);
+static char *_AudioType(int type);
+static char *_SubType(int type);
+static int NrOfSubp(vtsi_mat_t *vtsi_mat, pgc_t *pgc);
+static gint VideoSortString(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static gint VideoSortStringNBR(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static int SubpId(unsigned int control);
+static int AudioId(unsigned int control);
+static void AudioCheckToggled(GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
+static void SubCheckToggled(GtkCellRendererToggle *cell, gchar *path_str, gpointer data);
+static gint AudioSortString(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static gint AudioSortStringNBR(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static gint SubSortString(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static gint SubSortStringNBR(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata);
+static unsigned long GetSector(int chapitre, pgc_t *pgc);
+static unsigned short SubCode(int noPisteVideo, int noSubtitle);
+static double DefaultRequantFactor(int noPisteVideo, AudioMap_t *audioMap, SubMap_t *subMap, int useMenuF);
 #ifdef __cplusplus
 }
 #endif
-/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) []*/
 
+/***************************************************************************//**
+ *	_AUDIOFORMAT-
+ * @date	2009/06/04 20:45:14
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+static char * _AudioFormat( int format )
+{
+	switch( format ) {
+		case 0 :	return( _("AC3") );
+		case 1 : 	return( _("?") );
+		case 2 :	return( _("MPEG1") );
+		case 3 :	return( _("MPEG2") );
+		case 4 :	return( _("LPCM") );
+		case 5 :	return( _("SDDS") );
+		case 6 :	return( _("DTS") );
+	}
+	return( _("?") );
+}
+
+/***************************************************************************//**
+ *	_AUDIOTYPE-
+ * @date	2009/06/04 20:48:42
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+static char * _AudioType( int type )
+{
+	switch( type ) {
+		case 0 :	return( _("") );
+		case 1 :	return( _("Normal") );
+		case 2 :	return( _("Impaired") );
+		case 3 :	return( _("Director's comments") );
+		case 4 :	return( _("Alternate director's comments" ) );
+	}
+	return( _("") );
+}
+
+/***************************************************************************//**
+ *	_SUBTYPE-
+ * @date	2009/06/04 20:55:44
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+static char * _SubType( int type )
+{
+	switch( type ) {
+		case 0 : return( _("") );
+		case 1 : return( _("Normal") );
+		case 2 : return( _("Large") );
+		case 3 : return( _("Enfants") );
+		case 4 : return( _("Reserved") );
+		case 5 : return( _("Légende normale") );
+		case 6 : return( _("Légende large") );
+		case 7 : return( _("Légende enfants") );
+		case 8 : return( _("reserved") );
+		case 9 : return( _("Forcé") );
+		case 10 : return( _("reserved") );
+		case 11 : return( _("reserved") );
+		case 12 : return( _("reserved") );
+		case 13 : return( _("Réalisateur") );
+		case 14 : return( _("Réalisateur large") );
+		case 15 : return( _("Réalisateur enfants") );
+	}
+	return( _("") );
+}
 /*------------------------------------------------------------------------------
 	NROFSUBP-
 Linux!jef 2006/01/25 21:43:53
@@ -334,7 +431,7 @@ int ScanDvd( GtkWidget * forme )
 		piste->vts_pgcit = vts_pgcit;
 
 		if( vtsi_mat && vts_pgcit ) {
-			int k,l;
+			int k;
 			char langues[100];
 			audio_attr_t *audio_attr;
 			unsigned long sec;
@@ -357,14 +454,17 @@ int ScanDvd( GtkWidget * forme )
 
 					if( IsValidAudioTrack( pgc, k ) ) {
 						audio_attr = &vtsi_mat->vts_audio_attr[k];
-						sprintf( lang_code, "%c%c", audio_attr->lang_code >> 8,audio_attr->lang_code & 0xff);
-						if( !strstr( langues, lang_code ) ) {
-							if( *langues )	strcat( langues, "," );
-							strcat( langues, lang_code );
+						if( audio_attr->lang_code != 0xFFFF ) {
+							DBG('c',fprintf(stderr,"Audio code 0x%x\n", audio_attr->lang_code ););
+							sprintf( lang_code, "%c%c", audio_attr->lang_code >> 8,audio_attr->lang_code & 0xff);
+							if( !strstr( langues, lang_code ) ) {
+								if( *langues )	strcat( langues, "," );
+								strcat( langues, lang_code );
+							}
 						}
 					}
 					else {
-						DBG('c',fprintf(stderr,"Invalid audio track %d\n", k ););
+						DBG('c',fprintf(stderr,"Unavailable audio track %d\n", k ););
 					}
 				}
 				sec = BCD2INT( pgc->playback_time.hour ) * 3600;
@@ -560,7 +660,7 @@ int GetSubId( int noPisteVideo, int noPisteSub )
 {
 //	ifo_handle_t * ifo = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr];
 	Piste_t * piste = GetPiste(noPisteVideo);
-	ifo_handle_t * ifo = piste->ifo;
+//	ifo_handle_t * ifo = piste->ifo;
 	pgcit_t *vts_pgcit;
 	int title_set_nr;
 	int vts_ttn;
@@ -623,24 +723,36 @@ static void AudioCheckToggled( GtkCellRendererToggle *cell, gchar * path_str, gp
 	gboolean toggle_item;
 	gchar * langCode;
 	gchar * audioPref = ConfigGetString( KEY_AUDIO, "" );
+	gchar * audioFormat;
+	gchar * audioChannels;
+	char audioTag[50];
 
 // fprintf(stderr,"BLIP %p (%s)!\n", model, path_str );
 /* get toggled iter */
 	gtk_tree_model_get_iter( model, &iter, path);
 	gtk_tree_model_get( model, &iter, AUDIO_COL1_CHECK, &toggle_item, -1);
-	gtk_tree_model_get( model, &iter, AUDIO_COL6_LANGCODE, &langCode, -1);
+	gtk_tree_model_get( model, &iter, AUDIO_COL7_LANGCODE, &langCode, -1);
+	gtk_tree_model_get( model, &iter, AUDIO_COL4_FORMAT, &audioFormat, -1);
+	gtk_tree_model_get( model, &iter, AUDIO_COL6_CANAUX, &audioChannels, -1);
+
+/* Build audio tag to correctly select audio track */
+	sprintf( audioTag, "%s.%s.%s",
+				langCode,
+				audioFormat,
+				audioChannels );
+
 /* do something with the value */
 	toggle_item ^= 1;
-	CTEST(fprintf(stderr,"AudioPref=(%s)\n", audioPref ););
+	DBG('p',fprintf(stderr,"AudioPref=(%s) AudioTag(%s)\n", audioPref, audioTag ););
 	if( toggle_item ) {
-		CTEST(fprintf(stderr,"LangCode (%s) selected\n", langCode ););
-		audioPref = AddString2List( audioPref, langCode );
+		DBG('p',fprintf(stderr,"AudioTag (%s) selected\n", audioTag ););
+		audioPref = AddString2List( audioPref, audioTag );
 	}
 	else {
-		CTEST(fprintf(stderr,"LangCode (%s) unselected\n", langCode ););
-		audioPref = RemoveStringFromList( audioPref, langCode );
+		DBG('p',fprintf(stderr,"AudioTag (%s) unselected\n", audioTag ););
+		audioPref = RemoveStringFromList( audioPref, audioTag );
 	}
-	CTEST(fprintf(stderr,"AudioPref=(%s)\n", audioPref ););
+	DBG('p',fprintf(stderr,"AudioPref=(%s)\n", audioPref ););
 	SetConfigString( KEY_AUDIO, audioPref );
 	free( audioPref );
 /* set new value */
@@ -732,7 +844,7 @@ static gint AudioSortStringNBR( GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIte
 
 	switch (sortcol) {
 		case AUDIO_COL2_PISTE:
-		case AUDIO_COL5_CANAUX:
+		case AUDIO_COL6_CANAUX:
 			gtk_tree_model_get(model, a, sortcol, &name1, -1);
 			gtk_tree_model_get(model, b, sortcol, &name2, -1);
 			if( name1 == NULL || name2 == NULL ) {
@@ -844,7 +956,9 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 	AudioMap_t audioMap;
 	SubMap_t subMap;
 	Piste_t * piste = GetPiste( noPisteVideo );
+	Profile_t * p = GetProfile( GetFormat() );
 
+	g_assert( p );
 // fprintf(stderr,"%s-%d\n",__FILE__,__LINE__);
 	memset( &audioMap, 0, sizeof(audioMap));
 	memset( &subMap, 0, sizeof(subMap));
@@ -871,6 +985,7 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 					G_TYPE_STRING,
 					G_TYPE_STRING,
 					G_TYPE_STRING,
+					G_TYPE_STRING,
 					G_TYPE_INT );
 
 	g_assert( treestore );
@@ -883,7 +998,7 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 			"active",
 			AUDIO_COL1_CHECK,
 			NULL);
-/* Ajout de la colonne  la vue */
+/* Ajout de la colonne à la vue */
 	gtk_tree_view_append_column(GTK_TREE_VIEW(item), colCheck);
 
 /* La piste */
@@ -917,16 +1032,27 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 	gtk_tree_view_append_column(GTK_TREE_VIEW(item), col);
 	gtk_tree_view_column_set_sort_column_id( col, AUDIO_COL4_FORMAT );
 
+/* Extension */
+	renderer = gtk_cell_renderer_text_new();
+	col = gtk_tree_view_column_new_with_attributes(
+			_("Extension"),
+			renderer,
+			"text",
+			AUDIO_COL5_EXTENSION,
+			NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(item), col);
+	gtk_tree_view_column_set_sort_column_id( col, AUDIO_COL5_EXTENSION );
+
 /* Les canaux */
 	renderer = gtk_cell_renderer_text_new();
 	col = gtk_tree_view_column_new_with_attributes(
 			_("Canaux"),
 			renderer,
 			"text",
-			AUDIO_COL5_CANAUX,
+			AUDIO_COL6_CANAUX,
 			NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(item), col);
-	gtk_tree_view_column_set_sort_column_id( col, AUDIO_COL5_CANAUX );
+	gtk_tree_view_column_set_sort_column_id( col, AUDIO_COL6_CANAUX );
 
 //	vtsi_mat = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr]->vtsi_mat;
 //	vts_pgcit = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr]->vts_pgcit;
@@ -944,6 +1070,7 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 
 	for( k = 0; k < vtsi_mat->nr_of_vts_audio_streams;k++ ) {
 		char lang_code[3];
+		char audio_tag[50];
 
 		if( IsValidAudioTrack( pgc, k ) ) {
 			audio_attr = &vtsi_mat->vts_audio_attr[k];
@@ -958,17 +1085,26 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 			sprintf( string, _("%s"), DvdLangCode2String( lang_code ) );
 			gtk_tree_store_set( treestore, &iter, AUDIO_COL3_LANG, string, -1 );
 
-			sprintf( string, _("%s"), _AudioFormat[audio_attr->audio_format] );
+			sprintf( string, "%s", _AudioFormat(audio_attr->audio_format) );
 			gtk_tree_store_set( treestore, &iter, AUDIO_COL4_FORMAT, string, -1 );
 
+			sprintf( string, "%s", _AudioType(audio_attr->code_extension) );
+			gtk_tree_store_set( treestore, &iter, AUDIO_COL5_EXTENSION, string, -1 );
+
 			sprintf( string, _("%d"), audio_attr->channels + 1 );
-			gtk_tree_store_set( treestore, &iter, AUDIO_COL5_CANAUX, string, -1 );
+			gtk_tree_store_set( treestore, &iter, AUDIO_COL6_CANAUX, string, -1 );
 
-			gtk_tree_store_set( treestore, &iter, AUDIO_COL6_LANGCODE, lang_code, -1 );
+			gtk_tree_store_set( treestore, &iter, AUDIO_COL7_LANGCODE, lang_code, -1 );
 
-			gtk_tree_store_set( treestore, &iter, AUDIO_COL7_NO, k, -1 );
+			gtk_tree_store_set( treestore, &iter, AUDIO_COL8_NO, k, -1 );
 
-			if( strstr( audioPref, lang_code ) ) {
+/* Build audio tag to correctly select audio track */
+			sprintf( audio_tag, "%s.%s.%d",
+						lang_code,
+						_AudioFormat(audio_attr->audio_format),
+						audio_attr->channels + 1 );
+
+			if( strstr( audioPref, audio_tag ) ) {
 				gtk_tree_store_set( treestore, &iter, AUDIO_COL1_CHECK, 1, -1 );
 				audioMap.audioTracks[k] = 1;
 			}
@@ -996,9 +1132,9 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 						NULL);
 
 	 gtk_tree_sortable_set_sort_func(	GTK_TREE_SORTABLE( GTK_TREE_MODEL( treestore ) ),
-						AUDIO_COL5_CANAUX,
+						AUDIO_COL6_CANAUX,
 						AudioSortStringNBR,
-						(gpointer)AUDIO_COL5_CANAUX,
+						(gpointer)AUDIO_COL6_CANAUX,
 						NULL);
 
 
@@ -1018,7 +1154,6 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 
 	gtk_widget_show_all( item );
 	g_object_unref(treestore);
-
 /* Sous titres */
 	item = lookup_widget(GTK_WIDGET(forme), "SousTitres" );
 	g_assert( item );
@@ -1049,7 +1184,7 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 			"active",
 			SUB_COL1_CHECK,
 			NULL);
-/* Ajout de la colonne  la vue */
+/* Ajout de la colonne à la vue */
 	gtk_tree_view_append_column(GTK_TREE_VIEW(item), colCheck);
 
 /* La piste */
@@ -1083,7 +1218,6 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 	gtk_tree_view_append_column(GTK_TREE_VIEW(item), col);
 	gtk_tree_view_column_set_sort_column_id( col, SUB_COL4_EXT );
 
-
 //	vtsi_mat = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr]->vtsi_mat;
 //	vts_pgcit = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr]->vts_pgcit;
 	video_attr = &vtsi_mat->vts_video_attr;
@@ -1110,8 +1244,7 @@ int ScanPiste( GtkWidget * forme, int noPisteVideo )
 			sprintf( string, _("%s"), DvdLangCode2String( lang_code ) );
 			gtk_tree_store_set( treestore, &iter, SUB_COL3_LANG, string, -1 );
 
-//			sprintf( string, _("%s"), SubpType[subp_attr->lang_extension] );
-			sprintf( string, _("%s"), SubpType[subp_attr->code_extension] );
+			sprintf( string, "%s", _SubType(subp_attr->code_extension ) );
 			gtk_tree_store_set( treestore, &iter, SUB_COL4_EXT, string, -1 );
 
 			gtk_tree_store_set( treestore, &iter, SUB_COL5_LANGCODE, lang_code, -1 );
@@ -1179,7 +1312,11 @@ pgc_t * pgc;
 	int cell = 0;
 	unsigned int total = 0;
 
-	DBG('b',fprintf(stderr,"%s:>\n",__FUNCTION__););
+	DBG('b',fprintf(stderr,"%s:> #programs: %d\n",__FUNCTION__, pgc->nr_of_programs););
+	for( i = 0; i < pgc->nr_of_programs; i++ ) {
+		DBG('b',fprintf(stderr,"%s: Chapitre: %d Start=%d\n", __FUNCTION__, i+1, pgc->program_map[i] ););
+	}
+
 	for( i = 0; i < pgc->nr_of_programs; i++ ) {
 		unsigned int sectors = 0;
 		int next;
@@ -1188,9 +1325,13 @@ pgc_t * pgc;
 			next = pgc->nr_of_cells + 1;
 		else
 			next = pgc->program_map[i + 1];
+		DBG('b',fprintf(stderr,"%s: next: %d start=%d\n", __FUNCTION__, next, pgc->program_map[i] ););
 		while( cell < next - 1 ) {
-			unsigned int secSize
-				= pgc->cell_playback[cell].last_sector - pgc->cell_playback[cell].first_sector + 1;
+			unsigned int secSize;
+
+/* cell cannot index > nr_of_cells */
+			if( cell >= pgc->nr_of_cells )	break;
+			secSize	= pgc->cell_playback[cell].last_sector - pgc->cell_playback[cell].first_sector + 1;
 			DBG('b',fprintf(stderr,"%s: i=%d cell: %d secSize=%s from: %u to: %u\n", __FUNCTION__, i, cell, LLSize2Giga((long long)secSize * SECTOR_SIZE), pgc->cell_playback[cell].first_sector,pgc->cell_playback[cell].last_sector ););
 			sectors += secSize;
 			cell++;
@@ -1420,24 +1561,25 @@ void VisuDvdPiste( int noPisteVideo )
 {
 	char * player = ConfigGetString( KEY_PLAYER, "xine" );
 	char sysCmd[1024];
+	int res;
 
 	if( !strcmp( player, "xine" )) {
 		sprintf( sysCmd, "xine dvd:/%s", Device);
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 	if( !strcmp( player, "mplayer" )) {
 		sprintf( sysCmd, "mplayer -dvd-device %s dvd://%d", Device, noPisteVideo + 1 );
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 	if( !strcmp( player, "vlc" )) {
 		sprintf( sysCmd, "vlc dvd://%s@%d:1", Device, noPisteVideo + 1 );
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 	sprintf( sysCmd, "%s %s", player, Device );
-	system( sysCmd );
+	res  = system( sysCmd );
 }
 
 
@@ -1451,23 +1593,24 @@ char * path;
 {
 	char * player = ConfigGetString( KEY_PLAYER, "xine" );
 	char sysCmd[1024];
+	int res;
 
 	if( !strcmp( player, "xine" )) {
 		sprintf( sysCmd, "xine \"dvd://%s\"", path );
 		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 	if( !strcmp( player, "mplayer" )) {
 		sprintf( sysCmd, "mplayer -dvd-device \"%s\" dvd://1", path );
 		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 	if( !strcmp( player, "vlc" )) {
 		sprintf( sysCmd, "vlc \"dvd://%s@0:1\"", path );
 		DBG('c',fprintf(stderr,"%s: executing (%s)\n", __FUNCTION__, sysCmd ););
-		system( sysCmd );
+		res = system( sysCmd );
 		return;
 	}
 }
