@@ -134,6 +134,7 @@ int IdentifyStream( unsigned char * buffer, int * packetType )
     }
 	return stOther;
 }
+
 /*------------------------------------------------------------------------------
 	GETSTREAMID-
 Linux!jef 2006/01/18 22:49:32
@@ -307,6 +308,40 @@ char * AudioFormat( int noPisteVideo, int noPisteAudio )
 //!!	if( (audio_attr->channels + 1) == 6 )	return( "dts" );
 	return( _AudioFormat[audio_attr->audio_format] );
 }
+/***************************************************************************//**
+ *	AUDIOSTREAMID-
+ * @date	2009/06/03 22:19:15
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+int AudioStreamId(  int noPisteVideo, int noPisteAudio )
+{
+	vtsi_mat_t *vtsi_mat;
+	audio_attr_t *audio_attr;
+
+	vtsi_mat = Ifo[Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr]->vtsi_mat;
+
+	audio_attr = &vtsi_mat->vts_audio_attr[noPisteAudio];
+//!!	if( (audio_attr->channels + 1) == 6 )	return( "dts" );
+	switch( audio_attr->audio_format ) {
+		case 0 : /* AC3 */
+			return( 0x80 + noPisteAudio );
+		case 2 : /* Mpeg-1 */
+		case 3 : /* Mpeg-2 */
+			return( 0xC0 + noPisteAudio );
+		case 4: /* LPCM */
+			return( 0xA0 + noPisteAudio );
+		case 6: /* DTS */
+			return( 0x88 + noPisteAudio );
+		default :
+			return( 0x80 + noPisteAudio );
+	}
+}
 
 /*------------------------------------------------------------------------------
 	MYDVDREAD1BLOCK-
