@@ -40,28 +40,31 @@ typedef struct {
 } Piste_t;
 
 
-/*@$#[dvdtools.c] global proto. AutoProtoSigV1.1. date: 107/09/27 22:20:21 */
+/*@$#[dvdtools.c] global proto. AutoProtoSigV1.1. date: 2009/06/03 22:23:29 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
-int isNavPack PROTO((unsigned char *_ptr));
-int IdentifyStream PROTO((unsigned char *buffer, int *packetType));
-int GetStreamID PROTO((int type));
-char *BuildChapitreString PROTO((int noPisteVideo));
-void SavePalette PROTO((int noPisteVideo, char *pFile));
-char *AudioLang PROTO((int noPisteVideo, int noPisteAudio));
-char *SubLang PROTO((int noPisteVideo, int noSubtitle));
-char *AudioFormat PROTO((int noPisteVideo, int noPisteAudio));
-int MyDVDRead1Block PROTO((dvd_file_t *dvdFile, int noSect, void *buffer));
-Piste_t *GetPiste PROTO((int noPisteVideo));
-void RazPistes PROTO((void));
-void CreateDummyPack PROTO((unsigned char *buffer));
-void CreateDummyNavPack PROTO((unsigned char *buffer, unsigned int sector));
-int VerifNavPack PROTO((unsigned char *p));
+void CreateDummyNavPack(unsigned char *buffer, unsigned int sector);
+int VerifNavPack(unsigned char *p);
+int MilliSeconde(dvd_time_t *dt);
+int isNavPack(unsigned char *_ptr);
+int IdentifyStream(unsigned char *buffer, int *packetType);
+int GetStreamID(int type);
+pgc_t *GetPgc(int noPisteVideo);
+char *BuildChapitreString(int noPisteVideo);
+void SavePalette(int noPisteVideo, char *pFile);
+char *AudioLang(int noPisteVideo, int noPisteAudio);
+char *SubLang(int noPisteVideo, int noSubtitle);
+char *AudioFormat(int noPisteVideo, int noPisteAudio);
+int AudioStreamId(int noPisteVideo, int noPisteAudio);
+int MyDVDRead1Block(dvd_file_t *dvdFile, int noSect, void *buffer);
+Piste_t *GetPiste(int noPisteVideo);
+void RazPistes(void);
+void CreateDummyPack(unsigned char *buffer);
 #ifdef __cplusplus
 }
 #endif
-/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) []*/
 #endif	/* __DVDTOOLS_H__ */
 
