@@ -39,17 +39,28 @@ COMMENTAIRE :
 #define KEY_MAIN_PY	"/apps/dvd95/config/main-py"
 #define KEY_MAIN_MAX	"/apps/dvd95/config/main-max"
 
-void DialogPropriete( GtkWidget * parent );
-int LoadConfig( GtkWidget * propriete );
-int SaveConfig( GtkWidget * propriete );
-gchar * ConfigGetString( char * key, char * defValue );
-int VerifConfig( GtkWidget * propriete );
-int SetConfigString( char * key, char * value );
-void InitTrace();
-int ConfigGetInt( char * key, int defValue );
-void CreateDirectorys();
-void ConfigSetSizePosMain( GtkWidget * mainWindow );
-int SetConfigInt( char * key, int value );
-void ConfigRecordSizePosMain( GtkWidget * mainWindow );
+/*@$#[gconfig.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:20:03 */
+#include "proto.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
+/* gconfig.c */
+void DialogPropriete PROTO((GtkWidget *parent));
+int LoadConfig PROTO((GtkWidget *propriete));
+int SaveConfig PROTO((GtkWidget *propriete));
+gchar *ConfigGetString PROTO((char *key, char *defValue));
+int ConfigGetInt PROTO((char *key, int defValue));
+int SetConfigString PROTO((char *key, char *value));
+int SetConfigInt PROTO((char *key, int value));
+int VerifConfig PROTO((GtkWidget *propriete));
+void InitTrace PROTO((void));
+void CreateDirectorys PROTO((void));
+void ConfigSetSizePosMain PROTO((GtkWidget *mainWindow));
+void ConfigRecordSizePosMain PROTO((GtkWidget *mainWindow));
+#ifdef __cplusplus
+}
+#endif
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+
 #endif	/* __CONFIG_H__ */
 
