@@ -28,6 +28,7 @@ COMMENTAIRE :
 #   include <sys/mount.h>
 #else
 #	include <sys/statfs.h>
+#	include <sys/ioctl.h>
 #endif
 #include <fcntl.h>
 #include <unistd.h>
@@ -66,6 +67,18 @@ struct child
 #define PATHCHR		':'
 #define SEPCHAR		'/'
 
+/*@$#[systools.c] static proto. AutoProtoSigV1.1. date: 2009/02/04 23:22:17 */
+#include "proto.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
+/* systools.c */
+static GSList *testAndAppend PROTO((GSList *list, char *devName));
+#ifdef __cplusplus
+}
+#endif
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+
 /*------------------------------------------------------------------------------
 	MKFIFO-
 Linux!jef 2005/12/05 21:59:11
@@ -221,6 +234,24 @@ int DirExist( char * dirName )
 	if( S_ISDIR( bStat.st_mode ) )	return( 1 );
 	return( -1 );
 }
+
+/***************************************************************************//**
+ *	DIRCANWRITE-
+ * @date	2009/07/07 22:22:21
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+int DirCanWrite( char * dirname )
+{
+	if( access( dirname, W_OK ) )	return( -1 );
+	return( 0 );
+}
+
 /*------------------------------------------------------------------------------
 	FILEEXIST-
 Linux!jef 2006/01/31 21:02:35
@@ -648,6 +679,10 @@ GSList *getDevices( void )
 		sprintf( devName, "/dev/sr%d", i );
 		list = testAndAppend( list, devName );
 	}
+	for( i = 0; i < 10; i++ ) {
+		sprintf( devName, "/dev/scd%d", i );
+		list = testAndAppend( list, devName );
+	}
 /* Loop devices */
 	for( i = 0; i < 10; i++ ) {
 		sprintf( devName, "/dev/loop%d", i );
@@ -752,3 +787,81 @@ GSList *getDevices(void)
 	return list;
 }
 #endif
+/***************************************************************************//**
+ *	GETNUMCPU-
+ * @date	2009/01/15 23:40:20
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+int GetNumCpu()
+{
+	int	numcpu = sysconf( _SC_NPROCESSORS_ONLN );
+
+	if( numcpu < 1 )        numcpu = 1;
+	return( numcpu );
+}
+/***************************************************************************//**
+ *	CANCREATEFILE-
+ * @date	2009/01/27 23:05:23
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+int CanCreateFile( char * dirName )
+{
+	char * fName = alloca( strlen(dirName) + 1 + strlen( ".dvd95" ) + 1 );
+	FILE * fp;
+
+	sprintf( fName, "%s/.dvd95", dirName );
+	fp = fopen( fName, "w" );
+	if( !fp )	return( 0 );
+	fclose( fp );
+	unlink( fName );
+	return( 1 );
+}
+/***************************************************************************//**
+ *	GETMKISOTOOL-
+ * @date	2009/01/29 21:28:00
+ * @author	jef-Linux
+ * @brief
+ *	Return ISO builder tool name
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+
+char * GetMkIsoTool()
+{
+	if( flook( "genisoimage" ) )	return( "genisoimage" );
+	return( "mkisofs" );
+}
+
+/***************************************************************************//**
+ *	GETENV-
+ * @date	2009/07/07 21:52:07
+ * @author	jef-Linux
+ * @brief
+ *	Pas d'explication
+ * @details
+ *	Pas de details
+ * @param[in]	Pas de detail
+ * @param[out]	Pas de detail
+*******************************************************************************/
+char * GetEnv( char * evKey, char * defValue )
+{
+	char * envValue = getenv( evKey );
+	if( envValue )	return( envValue );
+	return( defValue );
+}
